@@ -106,6 +106,8 @@ class APIHarness:
         self.token_expiration = 0
         self.token_time = time.time()
         self.authenticated = False
+        self.token_fail_reason = None
+        self.token_status = None
         self.headers = lambda: {"Authorization": f"Bearer {self.token}"} if self.token else {}
         self.commands = api_endpoints
         self.user_agent = user_agent  # Issue #365
@@ -152,11 +154,13 @@ class APIHarness:
                                  user_agent=self.user_agent
                                  )
         if isinstance(result, dict):  # Issue #433
-            if result["status_code"] == 201:
+            self.token_status = result["status_code"]
+            if self.token_status == 201:
                 self.token = result["body"]["access_token"]
                 self.token_expiration = result["body"]["expires_in"]
                 self.token_time = time.time()
                 self.authenticated = True
+                self.token_fail_reason = None
                 # Swap to the correct region if they've provided the incorrect one
                 if "X-Cs-Region" not in result["headers"]:
                     # GovCloud autodiscovery is not currently supported
@@ -168,8 +172,13 @@ class APIHarness:
                     self.base_url = confirm_base_url(token_region.upper())
             else:
                 self.authenticated = False
+                if "errors" in result["body"]:
+                    if result["body"]["errors"]:
+                        self.token_fail_reason = result["body"]["errors"][0]["message"]
         else:
             self.authenticated = False
+            self.token_fail_reason = "Unexpected API response received"
+            self.token_status = 403
 
         return self.authenticated
 
